package main

import (
    "github.com/gin-gonic/gin"
    "github.com/prometheus/client_golang/prometheus"
    "github.com/prometheus/client_golang/prometheus/promhttp"
    "os"
    "strconv" // 新增导入用于类型转换‌:ml-citation{ref="2" data="citationList"}
)

var (
    httpRequests = prometheus.NewCounterVec(
        prometheus.CounterOpts{
            Name: "http_requests_total",
            Help: "Total HTTP requests",
        },
        []string{"status", "namespace", "pod"}, // 标签顺序需与参数一致‌:ml-citation{ref="3" data="citationList"}
    )
)

func init() {
    prometheus.MustRegister(httpRequests) // 注册指标到默认注册表‌:ml-citation{ref="4" data="citationList"}
}

func main() {
    r := gin.Default()

    // 获取主机名
    hostname, err := os.Hostname()
    if err != nil {
        hostname = "unknown-host"
    }

    // 注入 Kubernetes 环境变量‌:ml-citation{ref="5" data="citationList"}
    namespace := os.Getenv("NAMESPACE")
    podName := os.Getenv("POD_NAME")

    // 中间件：记录请求指标‌:ml-citation{ref="2" data="citationList"}
    r.Use(func(c *gin.Context) {
        c.Next() // 先处理请求再获取状态码‌:ml-citation{ref="6" data="citationList"}
        httpRequests.WithLabelValues(
            strconv.Itoa(c.Writer.Status()), // 强制转换 int 为 string‌:ml-citation{ref="2" data="citationList"}
            namespace,
            podName,
        ).Inc()
    })

    // 根路由
    r.GET("/", func(c *gin.Context) {
        c.String(200, "当前主机名: %s", hostname)
    })

    // Prometheus 指标端点‌:ml-citation{ref="4" data="citationList"}
    r.GET("/metrics", gin.WrapH(promhttp.Handler()))

    r.Run(":3000")
}

